#
# spec file for package applet-window-buttons
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf5_version 5.81
%define qt5_version 5.15

Name:           applet-window-buttons
Version:        0.11.1
Release:        2.3
Summary:        Plasma 5 applet to show window buttons in panels
License:        GPL-2.0-or-later
Group:          System/GUI/KDE
URL:            https://github.com/psifidotos/applet-window-buttons
Source:         https://github.com/psifidotos/applet-window-buttons/archive/%{version}/%{name}-%{version}.tar.gz
# Fix for building with 5.27, taken from: ;https://github.com/psifidotos/applet-window-buttons/pull/191
Patch0:         kdecoration-5.27.patch
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  kconfig-devel >= %{kf5_version}
BuildRequires:  kconfigwidgets-devel >= %{kf5_version}
BuildRequires:  kdeclarative-devel >= %{kf5_version}
BuildRequires:  kdoctools-devel >= %{kf5_version}
BuildRequires:  kglobalaccel-devel >= %{kf5_version}
BuildRequires:  ki18n-devel >= %{kf5_version}
BuildRequires:  kwindowsystem-devel >= %{kf5_version}
BuildRequires:  kxmlgui-devel >= %{kf5_version}
BuildRequires:  libSM-devel
BuildRequires:  plasma-framework-devel >= %{kf5_version}
BuildRequires:  plasma5-workspace-devel >= 5.27
BuildRequires:  cmake(KDecoration2) >= 5.27
BuildRequires:  cmake(Qt5Core) >= %{qt5_version}
BuildRequires:  cmake(Qt5DBus) >= %{qt5_version}
BuildRequires:  cmake(Qt5Quick) >= %{qt5_version}
BuildRequires:  cmake(Qt5QuickWidgets) >= %{qt5_version}
BuildRequires:  cmake(Qt5Widgets) >= %{qt5_version}
BuildRequires:  cmake(Qt5X11Extras) >= %{qt5_version}

%description
This is a Plasma 5 applet that shows the current window appmenu in
one's panels. This plasmoid is coming from Latte land, but it can also
support Plasma panels.

%prep
%autosetup -p1

%build
%cmake_kf5 -d build
%make_jobs

%install
%kf5_makeinstall -C build
%fdupes %{buildroot}

%files
%license LICENSE
%{_kf5_qmldir}/org/kde/appletdecoration
%dir %{_kf5_plasmadir}/plasmoids
%{_kf5_plasmadir}/plasmoids/org.kde.windowbuttons
%if %{pkg_vcmp cmake(KF5Plasma) < 5.84} || %{pkg_vcmp cmake(KF5Plasma) >= 5.89}
%{_kf5_servicesdir}/plasma-applet-org.kde.windowbuttons.desktop
%endif
%{_kf5_appstreamdir}/org.kde.windowbuttons.appdata.xml

%changelog
* Wed Feb 15 2023 Cor Blom <cornelis@solcon.nl>
- Add kdecoration-5.27.patch to fix build with Plasma 5.27
- Increase version requirement for plasma and kdecoration to 5.27
* Sat Feb 12 2022 Cor Blom <cornelis@solcon.nl>
- Update to 0.11.1:
  * Add missing version
* Sat Feb 12 2022 Cor Blom <cornelis@solcon.nl>
- Uupdate to 0.11.0:
  * support Plasma 5.24 way of discovering themes from theme engines
  * hide when preserveemptyspace is selected
* Wed Jan  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Fix installation (again) when using plasma-framework 5.89.
* Thu Nov  4 2021 Cor Blom <cornelis@solcon.nl>
- Update to 0.10.1:
  * fix glitches with slide-in/out animations
  * improve cpu and hard disk usage
  * remove all workarounds related to faulty buttons painting
  * respect and trust bug fixes in decorations provided with Plasma 5.23.2
* Thu Oct 21 2021 Cor Blom <cornelis@solcon.nl>
- Update to 0.10.0:
  * Support Plasma 5.23
  * Depend only on Plasma and KDecorations2 >=5.23
  * drop option for plasma panels to disable decoration on maximized
    windows
- Remove fix-for-plasma-5.23.patch, part of this release
* Thu Oct 21 2021 Cor Blom <cornelis@solcon.nl>
- Add fix-for-plasma-5.23.patch to fix build with Plasma 5.23
- This means Plasma 5.23 (specifically kdecoration) 5.23 is now
  the minumum requirement
* Sun Jul 18 2021 Christophe Giboudeaux <christophe@krop.fr>
- Fix the %%files section. plasma-framework >= 5.84 doesn't install
  desktop files in %%_kf5_servicesdir anymore.
* Tue May 11 2021 Cor Blom <cornelis@solcon.nl>
- Update to 0.9.0:
  * support Plasma 5.18 and 5.21
  * support aurorae monochrome icons with Latte auto-color functionality
  * support aurorae restore button
  * fix, do not hide buttons for AlwaysVisible
  * fix, do not hide button in Latte edit mode
  * fix, improve default based on Plasma values
  * fix, preserve empty space for hidden states when needed
  * remove no needed workarounds
  _ Remove fix-build-plasma-5.21.patch (part of release now)
* Wed Feb 24 2021 Cor Blom <cornelis@solcon.nl>
- Add fix-build-plasma-5.21.patch to fix compilation with Plasma
  5.21
* Thu Feb 13 2020 Cor Blom <cornelis@solcon.nl>
- Update to version 0.8.1:
  * fix compatibility with Plasma 5.18 (Rodrigo Pedra Brum)
  * never hide buttons for AlwaysVisible visibility state
* Tue Jan 28 2020 Cor Blom <cornelis@solcon.nl>
- Update source URL
* Tue Jan 28 2020 Cor Blom <cornelis@solcon.nl>
- Update to version 0.8.0:
  * fix which plasma theme colors are used for buttons when
    Colors:Plasma Theme is chosen
  * do not show buttons that the current window has disabled them,
    for example a window is NOT Closable; Close button becomes hidden in such case
  * hide buttons when the last active maximized window is minimized
    and there are no other shown windows
  * improve configuration window texts
  * create a new decoration only when it is really needed
  * reduce filesystem trackers for scheme colors files
  * use shared decoration between all buttons
  * set an object name for the shared decoration in order to be
    easily identified by KDecoration2 decorations
* Sun Nov 24 2019 Cor Blom <cornelis@solcon.nl>
- Update to version 0.7.0:
  * introduce a new Button Size percentage option and drop
    thickness margin in order to set the buttons size
  * introduce Hidden State in order for the user to choose how
    buttons should behave when they should not be shown. Currently
    two states are supported: Slide out and Preserve Empty Space
  * introduce a new Color Scheme based on current Plasma Theme
    used and make it also default
  * live preview for changes in the settings window
  * do not crash when the selected decoration does not exist in the
    systemm, for example it was uninstalled
  * update buttons for scheme changes
* Sun Sep  1 2019 Cor Blom <cornelis@solcon.nl>
- Update source URL
* Sun Sep  1 2019 Cor Blom <cornelis@solcon.nl>
- Update to version 0.6.0:
  * new visibility mode: At least one window is shown
  * option to draw buttons in inactive state (for both c++ and
    aurorae decorations)
  * fix the current buttons decoration discovery, the user can now
    change between different decorations and the buttons style is
    updated runtime
  * hide when the last maximized window is closed and the visibility
    mode is ActiveMaximized
  * fix multi-screens behavior for Latte panels
  * fix typo that broke builds at some systems
* Fri Jul 12 2019 Cor Blom <cornelis@solcon.nl>
- Update to version 0.5.0:
  * provide a relevant background for window buttons in configuration
    window to fix contrast issues
  * support new Latte v0.9 Communicator API
  * support new Latte v0.9 Windows Tracking interface when in Latte
    dock/panel
* Sun Jun 30 2019 Jan Engelhardt <jengelh@inai.de>
- Fix grammar in descriptions.
* Mon May 20 2019 Cor Blom <cornelis@solcon.nl>
- Update to 0.4:
  * add new KeepAbove button support (community contribution)
  * merge different versions into a single one. One version for all Plasma versions >= 5.12
  * close ComboBoxes after clicking
- Lower plasma requirement to 5.12 (should now work)
* Mon Mar  4 2019 Cor Blom <cornelis@solcon.nl>
- Update to 0.3.
* Sat Nov 17 2018 Cor Blom <cornelis@solcon.nl>
- Initial package
